from distutils.core import setup
setup(
    name='silooqba',
    packages=['silooqba'],
    version='1',
    license='MIT',
    description='wewew',
    author='Looq',
    author_email='looqifi@gmail.com',
    url='https://github.com/looqify/Instac',
    download_url='https://github.com/looqify/Instac/archive/refs/tags/v1.tar.gz',
    keywords=['looq'],
    install_requires=[
        'pycryptodomex',
        'PyNaCl',
    ],
    classifiers=[
        # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'Topic :: Software Development :: Build Tools',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.9',
    ],
)
